==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 * Input for the task that migrates PostgreSQL databases to Azure Database for PostgreSQL for online migrations
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source PostgreSQL
 * @property targetConnectionInfo Connection information for target Azure Database for PostgreSQL
 */
public data class MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse(
    public val selectedDatabases:
    List<MigratePostgreSqlAzureDbForPostgreSqlSyncDatabaseInputResponse>,
    public val sourceConnectionInfo: PostgreSqlConnectionInfoResponse,
    public val targetConnectionInfo: PostgreSqlConnectionInfoResponse,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse):
            MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse =
            MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse(
                selectedDatabases = javaType.selectedDatabases().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.MigratePostgreSqlAzureDbForPostgreSqlSyncDatabaseInputResponse.Companion.toKotlin(args0)
                    })
                }),
                sourceConnectionInfo = javaType.sourceConnectionInfo().let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.PostgreSqlConnectionInfoResponse.Companion.toKotlin(args0)
                }),
                targetConnectionInfo = javaType.targetConnectionInfo().let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.PostgreSqlConnectionInfoResponse.Companion.toKotlin(args0)
                }),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 * Input for the task that migrates PostgreSQL databases to Azure Database for PostgreSQL for online migrations
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source PostgreSQL
 * @property targetConnectionInfo Connection information for target Azure Database for PostgreSQL
 */
public data class MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse(
    public val selectedDatabases: List<MigratePostgreSqlAzureDbForPostgreSqlSyncDatabaseInputResponse>,
    public val sourceConnectionInfo: PostgreSqlConnectionInfoResponse,
    public val targetConnectionInfo: PostgreSqlConnectionInfoResponse,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse): MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse =
            MigratePostgreSqlAzureDbForPostgreSqlSyncTaskInputResponse(
                selectedDatabases = javaType.selectedDatabases().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.datamigration.kotlin.outputs.MigratePostgreSqlAzureDbForPostgreSqlSyncDatabaseInputResponse.Companion.toKotlin(args0)
                    })
                }),
                sourceConnectionInfo = javaType.sourceConnectionInfo().let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.PostgreSqlConnectionInfoResponse.Companion.toKotlin(args0)
                }),
                targetConnectionInfo = javaType.targetConnectionInfo().let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.PostgreSqlConnectionInfoResponse.Companion.toKotlin(args0)
                }),
            )
    }
}
